@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.2
+#!/usr/local/bin/python2.3
 
 # Written by Bram Cohen
 # see LICENSE.txt for license information
@@ -13,7 +13,7 @@ from btmakemetafile import calcsize, make_meta_file, ignore
 def dummy(x):
     pass
 
-def completedir(dir, url, flag = Event(), vc = dummy, fc = dummy, piece_length = None):
+def completedir(dir, url, flag = Event(), vc = dummy, fc = dummy, piece_len_pow2 = None):
     files = listdir(dir)
     files.sort()
     ext = '.torrent'
@@ -36,7 +36,7 @@ def completedir(dir, url, flag = Event(), vc = dummy, fc = dummy, piece_length =
         try:
             t = split(i)[-1] 
             if t not in ignore and t[0] != '.':
-                make_meta_file(i, url, flag = flag, progress = callback, progress_percent=0, piece_length = piece_length)
+                make_meta_file(i, url, flag = flag, progress = callback, progress_percent=0, piece_len_exp = piece_len_pow2)
         except ValueError:
             print_exc()
 
